@@ -139,12 +139,24 @@ rix_init <- function(project_path,
   rprofile_quoted <- nix_rprofile()
   rprofile_deparsed <- deparse_chr1(expr = rprofile_quoted, collapse = "\n")
   rprofile_file <- file.path(project_path, ".Rprofile")
-  rprofile_con <- file(rprofile_file, open = "wb", encoding = "native.enc")
 
   rprofile_text <- get_rprofile_text(rprofile_deparsed)
-  on.exit(close(rprofile_con))
-  write_rprofile <- function(rprofile_text, rprofile_file) {
+
+  # This function creates the connection, write the text
+  # and closes the connection
+  # Makes it "as pure as possible"
+  write_rprofile <- function(rprofile_text, rprofile_file, mode) {
+    create_rprofile_con <- function(rprofile_file, mode) {
+      rprofile_con <- file(
+        rprofile_file,
+        open = mode,
+        encoding = "native.enc"
+      )
+    }
+
+    rprofile_con <- create_rprofile_con(rprofile_file, mode)
     writeLines(enc2utf8(rprofile_text), rprofile_con, useBytes = TRUE)
+    on.exit(close(rprofile_con))
   }
 
   is_nix_r <- is_nix_r_session()
@@ -153,7 +165,13 @@ rix_init <- function(project_path,
   # signal message if not quiet
   message_r_session_nix_rstudio(is_nix_r, is_rstudio, message_type)
 
-  rprofile_exists <- file.exists(rprofile_file)
+  # Test for existence and size instead of only existence,
+  # as an active file connection makes the file exist, but is empty
+  # Consider empty files as not existing to avoid not writing
+  # .Rprofile
+  rprofile_exists <- file.exists(rprofile_file) &&
+    `!=`(file.size(rprofile_file), 0L)
+
   timestamp <- format(Sys.time(), "%Y-%m-%dT%H:%M:%S%z")
   rprofile_backup <- paste0(rprofile_file, "_backup_", timestamp)
 
@@ -167,7 +185,7 @@ rix_init <- function(project_path,
           )
         }
       } else {
-        write_rprofile(rprofile_text, rprofile_file = rprofile_con)
+        write_rprofile(rprofile_text, rprofile_file = rprofile_file, mode = "wb")
         if (isFALSE(is_quiet)) {
           message_rprofile(action_string = "Added", project_path = project_path)
         }
@@ -177,7 +195,7 @@ rix_init <- function(project_path,
     create_backup = {
       if (isTRUE(rprofile_exists)) {
         file.copy(from = rprofile_file, to = rprofile_backup)
-        write_rprofile(rprofile_text, rprofile_file = rprofile_con)
+        write_rprofile(rprofile_text, rprofile_file = rprofile_file, mode = "wb")
         if (isFALSE(is_quiet)) {
           cat(
             "\n==> Backed up existing `.Rprofile` in file:\n", rprofile_backup,
@@ -191,13 +209,20 @@ rix_init <- function(project_path,
 
         if (message_type == "verbose") {
           cat("\n* Current lines of local `.Rprofile` are\n:")
-          cat(readLines(con = rprofile_con), sep = "\n")
+          cat(readLines(con = rprofile_file), sep = "\n")
         }
         set_message_session_PATH(message_type = message_type)
+      } else {
+        cat("\n* No existing `.Rprofile` to backup, creating one instead...\n:")
+        rix_init(
+          project_path = project_path,
+          rprofile_action = "create_missing",
+          message_type = message_type
+        )
       }
     },
     overwrite = {
-      write_rprofile(rprofile_text, rprofile_file = rprofile_con)
+      write_rprofile(rprofile_text, rprofile_file = rprofile_file, mode = "wb")
       if (isTRUE(rprofile_exists)) {
         message_rprofile(
           action_string = "Overwrote", project_path = project_path
@@ -209,7 +234,7 @@ rix_init <- function(project_path,
       }
     },
     append = {
-      cat(paste0(rprofile_text, "\n"), file = rprofile_con, append = TRUE)
+      write_rprofile(rprofile_text, rprofile_file = rprofile_file, mode = "a+")
       message_rprofile(
         action_string = "Appended", project_path = project_path
       )
@@ -218,7 +243,7 @@ rix_init <- function(project_path,
 
   if (message_type == "verbose") {
     cat("\n\n* Current lines of local `.Rprofile` are:\n\n")
-    cat(readLines(con = rprofile_action), sep = "\n")
+    cat(readLines(con = rprofile_file), sep = "\n")
   }
 }
 
